==> crypto-2.6.1.tgz: package/Unity/Unity.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Unity = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm-2.712-9.268c.866.132 1.74.198 2.617.197 2.976 0 5.677-.743 7.66-1.948-2.434-3.414-6.087-8.182-9.913-9.546a8.25 8.25 0 00-2.78-.48c-1.002 0-1.826.19-2.478.562-.653.373-.977.847-.977 1.408-.001.212.052.422.157.61.12.203.284.381.48.522.545.39 1.722.637 3.536.748.832.047 1.48.09 1.937.149 1.345.144 2.41.559 3.198 1.242.785.685 1.178 1.522 1.178 2.522 0 1.186-.537 2.164-1.612 2.934-.81.576-1.81.936-3 1.08zM9.009 20.79a8.86 8.86 0 003.011.545c1.226 0 2.222-.249 2.987-.747s1.149-1.139 1.149-1.922c0-.623-.275-1.134-.825-1.534-1.63-1.19-5.594-.591-7.749-1.527-.616-.287-1.088-.652-1.407-1.1a2.549 2.549 0 01-.463-1.201c-1.725 3.06-.196 6.21 3.297 7.486zm16.903-1.915c.657-.89 1.024-1.881 1.024-2.927 0-1.045-.367-2.038-1.024-2.927zm-1.649-7.46C22.24 9.936 19.244 9 15.905 9a16.87 16.87 0 00-4.077.49c.78.074 1.55.234 2.293.477 4.303 1.398 7.804 5.583 10.147 8.91z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "nonzero",
    d: "M25.912 18.875v-5.854c.657.889 1.024 1.882 1.024 2.927 0 1.046-.367 2.037-1.024 2.927zm-1.649-7.46l.005 7.461c-2.343-3.326-5.844-7.511-10.147-8.909a10.616 10.616 0 00-2.293-.477A16.87 16.87 0 0115.905 9c3.34 0 6.335.936 8.358 2.415z",
    opacity: .5
  })));
});
Unity.displayName = 'Unity';
export const UnityDimensions = {
  height: 32,
  width: 32
};

==> crypto-2.7.1.tgz: package/Unity/Unity.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Unity = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm-2.712-9.268c.866.132 1.74.198 2.617.197 2.976 0 5.677-.743 7.66-1.948-2.434-3.414-6.087-8.182-9.913-9.546a8.25 8.25 0 00-2.78-.48c-1.002 0-1.826.19-2.478.562-.653.373-.977.847-.977 1.408-.001.212.052.422.157.61.12.203.284.381.48.522.545.39 1.722.637 3.536.748.832.047 1.48.09 1.937.149 1.345.144 2.41.559 3.198 1.242.785.685 1.178 1.522 1.178 2.522 0 1.186-.537 2.164-1.612 2.934-.81.576-1.81.936-3 1.08zM9.009 20.79a8.86 8.86 0 003.011.545c1.226 0 2.222-.249 2.987-.747s1.149-1.139 1.149-1.922c0-.623-.275-1.134-.825-1.534-1.63-1.19-5.594-.591-7.749-1.527-.616-.287-1.088-.652-1.407-1.1a2.549 2.549 0 01-.463-1.201c-1.725 3.06-.196 6.21 3.297 7.486zm16.903-1.915c.657-.89 1.024-1.881 1.024-2.927 0-1.045-.367-2.038-1.024-2.927zm-1.649-7.46C22.24 9.936 19.244 9 15.905 9a16.87 16.87 0 00-4.077.49c.78.074 1.55.234 2.293.477 4.303 1.398 7.804 5.583 10.147 8.91z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "nonzero",
    d: "M25.912 18.875v-5.854c.657.889 1.024 1.882 1.024 2.927 0 1.046-.367 2.037-1.024 2.927zm-1.649-7.46l.005 7.461c-2.343-3.326-5.844-7.511-10.147-8.909a10.616 10.616 0 00-2.293-.477A16.87 16.87 0 0115.905 9c3.34 0 6.335.936 8.358 2.415z",
    opacity: .5
  })));
});
Unity.displayName = 'Unity';
export var UnityDimensions = {
  height: 32,
  width: 32
};
